==> 0.0.1.tar.gz: lib/src/widgets/tables/filter_view.dart <==
import 'package:collection/collection.dart';
import 'package:verttice_ui/src/const/box_sizes.dart';
import 'package:verttice_ui/src/const/icons.dart';
import 'package:verttice_ui/models/filters/filter_field.dart';
import 'package:verttice_ui/src/form_factory/form_factory.dart';
import 'package:verttice_ui/src/tables/table_utils.dart';
import 'package:verttice_ui/src/themed_app_bar.dart';
import 'package:flutter/material.dart';
import 'package:uuid/uuid.dart';

class FilterView extends StatefulWidget {
  final Function(Map<dynamic, FilterField>) filterCallback;
  final Function() clearFilterCallback;
  final Map<dynamic, FilterField>? filter;
  final FormItem column;

  const FilterView({
    Key? key,
    required this.filterCallback,
    required this.clearFilterCallback,
    required this.column,
    this.filter,
  }) : super(key: key);

  @override
  State<FilterView> createState() => _FilterViewState();
}

class _FilterViewState extends State<FilterView> {
  late Map<dynamic, FilterField> _filter;

  @override
  void initState() {
    super.initState();
    if (widget.filter == null) {
      _filter = {
        const Uuid().v4(): FilterField(
          field: widget.column.field.pathToField != null
              ? widget.column.field.pathToField!.join(".")
              : widget.column.field.name,
          filterType: widget.column.field.filterType,
        )
      };
    } else {
      _filter = widget.filter!;
    }
  }

  @override
  void didUpdateWidget(covariant FilterView oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (!const MapEquality().equals(_filter, widget.filter)) {
      if (widget.filter == null) {
        _filter = {
          const Uuid().v4(): FilterField(
            field: widget.column.field.pathToField != null
                ? widget.column.field.pathToField!.join(".")
                : widget.column.field.name,
            filterType: widget.column.field.filterType,
          )
        };
      } else {
        _filter = widget.filter!;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        ThemedAppBar(
          actions: [
            if (isTextField(widget.column))
              Tooltip(
                message: 'Add filter',
                child: IconButton(
                  onPressed: () {
                    setState(() {
                      _filter[const Uuid().v4()] = FilterField(
                        field: widget.column.field.pathToField != null
                            ? widget.column.field.pathToField!.join(".")
                            : widget.column.field.name,
                        filterType: widget.column.field.filterType,
                      );
                    });
                  },
                  icon: ThemedIcons.add(),
                ),
              )
          ],
        ),
        Expanded(
          child: !isTextField(widget.column)
              ? Center(
                  child: FormFactory(
                    formItems: [widget.column],
                    gridView: true,
                    isFilter: true,
                    formState: {
                      widget.column.field.name: _filter.values.first.value
                    },
                    onChanged: (name, data) {
                      setState(() {
                        _filter[_filter.keys.first] = FilterField(
                          field: widget.column.field.pathToField != null
                              ? widget.column.field.pathToField!.join(".")
                              : widget.column.field.name,
                          filterType: widget.column.field.filterType,
                          value: data,
                        );
                      });
                    },
                  ),
                )
              : ListView(
                  children: _filter.entries
                      .map(
                        (e) => MapEntry(
                          e.key,
                          Row(
                            crossAxisAlignment: CrossAxisAlignment.center,
                            mainAxisAlignment: MainAxisAlignment.spaceAround,
                            children: [
                              Expanded(
                                child: FormFactory(
                                  formItems: [widget.column],
                                  gridView: true,
                                  isFilter: true,
                                  formState: {
                                    widget.column.field.name: e.value.value
                                  },
                                  onChanged: (name, data) {
                                    setState(() {
                                      _filter[e.key] = FilterField(
                                        field: widget
                                                    .column.field.pathToField !=
                                                null
                                            ? widget.column.field.pathToField!
                                                .join(".")
                                            : widget.column.field.name,
                                        filterType:
                                            widget.column.field.filterType,
                                        value: data,
                                      );
                                    });
                                  },
                                ),
                              ),
                              if (_filter.entries.length > 1)
                                Padding(
                                  padding: const EdgeInsets.all(12.0),
                                  child: Tooltip(
                                    message: 'Remove this filter',
                                    child: IconButton(
                                      onPressed: () {
                                        setState(() {
                                          _filter.remove(e.key);
                                        });
                                      },
                                      icon: ThemedIcons.clear(),
                                    ),
                                  ),
                                )
                            ],
                          ),
                        ),
                      )
                      .map((e) => e.value)
                      .toList(),
                ),
        ),
        SizedBox(
          height: 50,
          child: Row(children: [
            sizedBoxW8,
            TextButton(
              onPressed: () {
                widget.clearFilterCallback();
                Navigator.of(context).pop();
              },
              child: const Text(
                'Clear Filter',
                style: TextStyle(
                  color: Colors.red,
                ),
              ),
            ),
            sizedBoxW8,
            TextButton(
              onPressed: () {
                widget.filterCallback(_filter);
                Navigator.of(context).pop();
              },
              child: const Text(
                'Apply Filter',
                style: TextStyle(
                  color: Colors.green,
                ),
              ),
            ),
            sizedBoxW8,
            Tooltip(
              message: "Cancel",
              child: TextButton(
                onPressed: () {
                  Navigator.of(context).pop();
                },
                child: const Text("Cancel"),
              ),
            ),
            sizedBoxW8,
          ]),
        )
      ],
    );
  }
}

==> 0.0.13.tar.gz: lib/src/widgets/tables/filter_view.dart <==
import 'package:collection/collection.dart';
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_ui/src/const/box_sizes.dart';
import 'package:verttice_ui/src/const/icons.dart';
import 'package:flutter/material.dart';
import 'package:uuid/uuid.dart';
import 'package:verttice_ui/src/widgets/form_factory/form_factory.dart';
import 'package:verttice_ui/src/widgets/tables/table_utils.dart';
import 'package:verttice_ui/src/widgets/themed_app_bar.dart';

class FilterView extends StatefulWidget {
  final Function(Map<dynamic, FilterField>) filterCallback;
  final Function() clearFilterCallback;
  final Map<dynamic, FilterField>? filter;
  final FormItem column;

  const FilterView({
    Key? key,
    required this.filterCallback,
    required this.clearFilterCallback,
    required this.column,
    this.filter,
  }) : super(key: key);

  @override
  State<FilterView> createState() => _FilterViewState();
}

class _FilterViewState extends State<FilterView> {
  late Map<dynamic, FilterField> _filter;

  @override
  void initState() {
    super.initState();
    if (widget.filter == null) {
      _filter = {
        const Uuid().v4(): FilterField(
          field: widget.column.field.pathToField != null
              ? widget.column.field.pathToField!.join(".")
              : widget.column.field.name,
          filterType: widget.column.field.filterType,
        )
      };
    } else {
      _filter = widget.filter!;
    }
  }

  @override
  void didUpdateWidget(covariant FilterView oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (!const MapEquality().equals(_filter, widget.filter)) {
      if (widget.filter == null) {
        _filter = {
          const Uuid().v4(): FilterField(
            field: widget.column.field.pathToField != null
                ? widget.column.field.pathToField!.join(".")
                : widget.column.field.name,
            filterType: widget.column.field.filterType,
          )
        };
      } else {
        _filter = widget.filter!;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        ThemedAppBar(
          actions: [
            if (isTextField(widget.column))
              Tooltip(
                message: 'Add filter',
                child: IconButton(
                  onPressed: () {
                    setState(() {
                      _filter[const Uuid().v4()] = FilterField(
                        field: widget.column.field.pathToField != null
                            ? widget.column.field.pathToField!.join(".")
                            : widget.column.field.name,
                        filterType: widget.column.field.filterType,
                      );
                    });
                  },
                  icon: ThemedIcons.add(),
                ),
              )
          ],
        ),
        Expanded(
          child: !isTextField(widget.column)
              ? Center(
                  child: FormFactory(
                    formItems: [widget.column],
                    gridView: true,
                    isFilter: true,
                    formState: {
                      widget.column.field.name: _filter.values.first.value
                    },
                    onChanged: (name, data) {
                      setState(() {
                        _filter[_filter.keys.first] = FilterField(
                          field: widget.column.field.pathToField != null
                              ? widget.column.field.pathToField!.join(".")
                              : widget.column.field.name,
                          filterType: widget.column.field.filterType,
                          value: data,
                        );
                      });
                    },
                  ),
                )
              : ListView(
                  children: _filter.entries
                      .map(
                        (e) => MapEntry(
                          e.key,
                          Row(
                            crossAxisAlignment: CrossAxisAlignment.center,
                            mainAxisAlignment: MainAxisAlignment.spaceAround,
                            children: [
                              Expanded(
                                child: FormFactory(
                                  formItems: [widget.column],
                                  gridView: true,
                                  isFilter: true,
                                  formState: {
                                    widget.column.field.name: e.value.value
                                  },
                                  onChanged: (name, data) {
                                    setState(() {
                                      _filter[e.key] = FilterField(
                                        field: widget
                                                    .column.field.pathToField !=
                                                null
                                            ? widget.column.field.pathToField!
                                                .join(".")
                                            : widget.column.field.name,
                                        filterType:
                                            widget.column.field.filterType,
                                        value: data,
                                      );
                                    });
                                  },
                                ),
                              ),
                              if (_filter.entries.length > 1)
                                Padding(
                                  padding: const EdgeInsets.all(12.0),
                                  child: Tooltip(
                                    message: 'Remove this filter',
                                    child: IconButton(
                                      onPressed: () {
                                        setState(() {
                                          _filter.remove(e.key);
                                        });
                                      },
                                      icon: ThemedIcons.clear(),
                                    ),
                                  ),
                                )
                            ],
                          ),
                        ),
                      )
                      .map((e) => e.value)
                      .toList(),
                ),
        ),
        SizedBox(
          height: 50,
          child: Row(children: [
            sizedBoxW8,
            TextButton(
              onPressed: () {
                widget.clearFilterCallback();
                Navigator.of(context).pop();
              },
              child: const Text(
                'Clear Filter',
                style: TextStyle(
                  color: Colors.red,
                ),
              ),
            ),
            sizedBoxW8,
            TextButton(
              onPressed: () {
                widget.filterCallback(_filter);
                Navigator.of(context).pop();
              },
              child: const Text(
                'Apply Filter',
                style: TextStyle(
                  color: Colors.green,
                ),
              ),
            ),
            sizedBoxW8,
            Tooltip(
              message: "Cancel",
              child: TextButton(
                onPressed: () {
                  Navigator.of(context).pop();
                },
                child: const Text("Cancel"),
              ),
            ),
            sizedBoxW8,
          ]),
        )
      ],
    );
  }
}
